pub enum VoteInstruction {
Show 20 variants
InitializeAccount(VoteInit),
Authorize(Address, VoteAuthorize),
Vote(Vote),
Withdraw(u64),
UpdateValidatorIdentity,
UpdateCommission(u8),
VoteSwitch(Vote, Hash),
AuthorizeChecked(VoteAuthorize),
UpdateVoteState(VoteStateUpdate),
UpdateVoteStateSwitch(VoteStateUpdate, Hash),
AuthorizeWithSeed(VoteAuthorizeWithSeedArgs),
AuthorizeCheckedWithSeed(VoteAuthorizeCheckedWithSeedArgs),
CompactUpdateVoteState(VoteStateUpdate),
CompactUpdateVoteStateSwitch(VoteStateUpdate, Hash),
TowerSync(TowerSync),
TowerSyncSwitch(TowerSync, Hash),
InitializeAccountV2(VoteInitV2),
UpdateCommissionCollector(CommissionKind),
UpdateCommissionBps {
commission_bps: u16,
kind: CommissionKind,
},
DepositDelegatorRewards {
deposit: u64,
},
}Variants
InitializeAccount(VoteInit)
Initialize a vote account
Account references
[WRITE]Uninitialized vote account[]Rent sysvar[]Clock sysvar[SIGNER]New validator identity (node_pubkey)
Authorize(Address, VoteAuthorize)
Authorize a key to send votes or issue a withdrawal
Account references
[WRITE]Vote account to be updated with the Pubkey for authorization[]Clock sysvar[SIGNER]Vote or withdraw authority
When SIMD-0387 is enabled, the VoteAuthorize::Voter variant is
disallowed for any vote accounts whose BLS pubkey is set to Some.
Vote(Vote)
A Vote instruction with recent votes
Account references
[WRITE]Vote account to vote with[]Slot hashes sysvar[]Clock sysvar[SIGNER]Vote authority
Withdraw(u64)
Withdraw some amount of funds
Account references
[WRITE]Vote account to withdraw from[WRITE]Recipient account[SIGNER]Withdraw authority
UpdateValidatorIdentity
Update the vote account’s validator identity (node_pubkey)
Account references
[WRITE]Vote account to be updated with the given authority public key[SIGNER]New validator identity (node_pubkey)[SIGNER]Withdraw authority
UpdateCommission(u8)
Update the commission for the vote account
Account references
[WRITE]Vote account to be updated[SIGNER]Withdraw authority
VoteSwitch(Vote, Hash)
A Vote instruction with recent votes
Account references
[WRITE]Vote account to vote with[]Slot hashes sysvar[]Clock sysvar[SIGNER]Vote authority
AuthorizeChecked(VoteAuthorize)
Authorize a key to send votes or issue a withdrawal
This instruction behaves like Authorize with the additional requirement that the new vote
or withdraw authority must also be a signer.
Account references
[WRITE]Vote account to be updated with the Pubkey for authorization[]Clock sysvar[SIGNER]Vote or withdraw authority[SIGNER]New vote or withdraw authority
When SIMD-0387 is enabled, the VoteAuthorize::Voter variant is
disallowed for any vote accounts whose BLS pubkey is set to Some.
UpdateVoteState(VoteStateUpdate)
Update the onchain vote state for the signer.
Account references
[Write]Vote account to vote with[SIGNER]Vote authority
UpdateVoteStateSwitch(VoteStateUpdate, Hash)
Update the onchain vote state for the signer along with a switching proof.
Account references
[Write]Vote account to vote with[SIGNER]Vote authority
AuthorizeWithSeed(VoteAuthorizeWithSeedArgs)
Given that the current Voter or Withdrawer authority is a derived key, this instruction allows someone who can sign for that derived key’s base key to authorize a new Voter or Withdrawer for a vote account.
Account references
[Write]Vote account to be updated[]Clock sysvar[SIGNER]Base key of current Voter or Withdrawer authority’s derived key
When SIMD-0387 is enabled, the VoteAuthorize::Voter variant in
authorization_type is disallowed for any vote accounts whose BLS
pubkey is set to Some.
AuthorizeCheckedWithSeed(VoteAuthorizeCheckedWithSeedArgs)
Given that the current Voter or Withdrawer authority is a derived key, this instruction allows someone who can sign for that derived key’s base key to authorize a new Voter or Withdrawer for a vote account.
This instruction behaves like AuthorizeWithSeed with the additional requirement
that the new vote or withdraw authority must also be a signer.
Account references
[Write]Vote account to be updated[]Clock sysvar[SIGNER]Base key of current Voter or Withdrawer authority’s derived key[SIGNER]New vote or withdraw authority
When SIMD-0387 is enabled, the VoteAuthorize::Voter variant in
authorization_type is disallowed for any vote accounts whose BLS
pubkey is set to Some.
CompactUpdateVoteState(VoteStateUpdate)
Update the onchain vote state for the signer.
Account references
[Write]Vote account to vote with[SIGNER]Vote authority
CompactUpdateVoteStateSwitch(VoteStateUpdate, Hash)
Update the onchain vote state for the signer along with a switching proof.
Account references
[Write]Vote account to vote with[SIGNER]Vote authority
TowerSync(TowerSync)
Sync the onchain vote state with local tower
Account references
[Write]Vote account to vote with[SIGNER]Vote authority
TowerSyncSwitch(TowerSync, Hash)
Sync the onchain vote state with local tower along with a switching proof
Account references
[Write]Vote account to vote with[SIGNER]Vote authority
InitializeAccountV2(VoteInitV2)
Initialize a vote account with all vote state v4 fields, including BLS public key and collector accounts.
The vote program performs BLS proof-of-possession verification on the
submitted BLS public key (per SIMD-0387). For each collector account
(indices 2 and 3), the program performs the same validation as
UpdateCommissionCollector (per SIMD-0232): if the collector is not
the vote account itself, it must be system-program owned, rent-exempt,
and writable (not a reserved account).
Account references
[WRITE]Uninitialized vote account[SIGNER]New validator identity (node_pubkey)[WRITE]Inflation rewards collector[WRITE]Block revenue collector
UpdateCommissionCollector(CommissionKind)
Update the commission collector for the vote account
Account references
[WRITE]Vote account to be updated with the new collector public key[WRITE]New collector account. Must be set to the vote account or a system program owned account. Must be writable to ensure the account is not reserved.[SIGNER]Vote account withdraw authority
UpdateCommissionBps
Update the commission rate in basis points for the specified commission rate kind in a vote account.
Account references
[WRITE]Vote account to be updated with the new commission[SIGNER]Vote account withdraw authority
DepositDelegatorRewards
Deposit lamports for distribution to stake delegators
Account references
[WRITE]Vote account to be updated with the deposit[SIGNER, WRITE]Source account for deposit funds
Implementations
Sourceimpl VoteInstruction
impl VoteInstruction
pub fn is_simple_vote(&self) -> bool
pub fn is_single_vote_state_update(&self) -> bool
Sourcepub fn last_voted_slot(&self) -> Option<u64>
pub fn last_voted_slot(&self) -> Option<u64>
Only to be used on vote instructions (guard with is_simple_vote), panics otherwise