Module handler

Module handler 

Vote state handler API.

Wraps the vote state behind a “handler” API to support converting from an existing vote state version to whichever version is the target (or “current”) vote state version.

The program must be generic over whichever vote state version is the target, since at compile time the target version is not known (can be changed with a feature gate). For this reason, the handler offers a getter and setter API around vote state, for all operations required by the vote program.

Structs

VoteStateHandler
Vote state handler for

Enums

VoteStateTargetVersion
The target version to convert all deserialized vote state into.