pub struct VoteStateV4 {Show 13 fields
pub node_pubkey: Address,
pub authorized_withdrawer: Address,
pub inflation_rewards_collector: Address,
pub block_revenue_collector: Address,
pub inflation_rewards_commission_bps: u16,
pub block_revenue_commission_bps: u16,
pub pending_delegator_rewards: u64,
pub bls_pubkey_compressed: Option<[u8; 48]>,
pub votes: VecDeque<LandedVote>,
pub root_slot: Option<u64>,
pub authorized_voters: AuthorizedVoters,
pub epoch_credits: Vec<(u64, u64, u64)>,
pub last_timestamp: BlockTimestamp,
}Fields
node_pubkey: AddressThe node that votes in this account.
The signer for withdrawals.
inflation_rewards_collector: AddressThe collector account for inflation rewards.
block_revenue_collector: AddressThe collector account for block revenue.
inflation_rewards_commission_bps: u16Basis points (0-10,000) that represent how much of the inflation rewards should be given to this vote account.
block_revenue_commission_bps: u16Basis points (0-10,000) that represent how much of the block revenue should be given to this vote account.
pending_delegator_rewards: u64Reward amount pending distribution to stake delegators.
bls_pubkey_compressed: Option<[u8; 48]>Compressed BLS pubkey for Alpenglow.
votes: VecDeque<LandedVote>root_slot: Option<u64>The signer for vote transactions. Contains entries for the current epoch and the previous epoch.
epoch_credits: Vec<(u64, u64, u64)>History of credits earned by the end of each epoch. Each tuple is (Epoch, credits, prev_credits).
last_timestamp: BlockTimestampMost recent timestamp submitted with a vote.
Implementations
Sourceimpl VoteStateV4
impl VoteStateV4
Sourcepub const fn size_of() -> usize
pub const fn size_of() -> usize
Upper limit on the size of the Vote State when votes.len() is MAX_LOCKOUT_HISTORY.
pub fn new_with_defaults( vote_pubkey: &Address, vote_init: &VoteInit, clock: &Clock, ) -> VoteStateV4
Sourcepub fn new(
vote_init: &VoteInitV2,
inflation_rewards_collector: &Address,
block_revenue_collector: &Address,
clock: &Clock,
) -> VoteStateV4
pub fn new( vote_init: &VoteInitV2, inflation_rewards_collector: &Address, block_revenue_collector: &Address, clock: &Clock, ) -> VoteStateV4
Creates a new VoteStateV4 from a VoteInitV2 and the collector
account addresses.
pub fn deserialize( input: &[u8], vote_pubkey: &Address, ) -> Result<VoteStateV4, InstructionError>
Sourcepub fn deserialize_into(
input: &[u8],
vote_state: &mut VoteStateV4,
vote_pubkey: &Address,
) -> Result<(), InstructionError>
pub fn deserialize_into( input: &[u8], vote_state: &mut VoteStateV4, vote_pubkey: &Address, ) -> Result<(), InstructionError>
Deserializes the input VoteStateVersions buffer directly into the provided VoteStateV4.
V0_23_5 is not supported. Supported versions: V1_14_11, V3, V4.
On success, vote_state reflects the state of the input data. On failure, vote_state is
reset to VoteStateV4::default().
Sourcepub fn deserialize_into_uninit(
input: &[u8],
vote_state: &mut MaybeUninit<VoteStateV4>,
vote_pubkey: &Address,
) -> Result<(), InstructionError>
pub fn deserialize_into_uninit( input: &[u8], vote_state: &mut MaybeUninit<VoteStateV4>, vote_pubkey: &Address, ) -> Result<(), InstructionError>
Deserializes the input VoteStateVersions buffer directly into the provided
MaybeUninit<VoteStateV4>.
V0_23_5 is not supported. Supported versions: V1_14_11, V3, V4.
On success, vote_state is fully initialized and can be converted to
VoteStateV4 using
MaybeUninit::assume_init.
On failure, vote_state may still be uninitialized and must not be
converted to VoteStateV4.
pub fn serialize( versioned: &VoteStateVersions, output: &mut [u8], ) -> Result<(), InstructionError>
pub fn is_correct_size_and_initialized(data: &[u8]) -> bool