Module vote_state

Module vote_state 

👎Deprecated since 3.1.0:

This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.

Vote state, vote program Receive and processes votes from validators

Modules

serde_compact_vote_state_update
serde_tower_sync
vote_state_1_14_11
vote_state_v3
vote_state_v4
vote_state_versions

Structs

BlockTimestamp
CircBuf
LandedVote
Lockout
TowerSync
Vote
VoteAuthorizeCheckedWithSeedArgs
VoteAuthorizeWithSeedArgs
VoteInit
VoteState1_14_11
VoteStateUpdate
VoteStateV3
VoteStateV4

Enums

VoteAuthorize
VoteStateVersions

Constants

BLS_PUBLIC_KEY_COMPRESSED_SIZE
Size of a BLS public key in a compressed point representation
INITIAL_LOCKOUT
MAX_EPOCH_CREDITS_HISTORY
MAX_LOCKOUT_HISTORY
VOTE_CREDITS_GRACE_SLOTS
VOTE_CREDITS_MAXIMUM_PER_SLOT

Functions

authorizeDeprecated
Authorize the given pubkey to withdraw or sign votes. This may be called multiple times, but will implicitly withdraw authorization from the previously authorized key
create_v3_account_with_authorizedDeprecated
create_v4_account_with_authorizedDeprecated
do_process_vote_state_updateDeprecated
initialize_accountDeprecated
Initialize the vote_state for a vote account Assumes that the account is being init as part of a account creation or balance transfer and that the transaction must be signed by the staker’s keys
is_commission_update_allowedDeprecated
Given the current slot and epoch schedule, determine if a commission change is allowed
process_new_vote_stateDeprecated
process_slot_vote_uncheckedDeprecated
process_tower_syncDeprecated
process_voteDeprecated
process_vote_state_updateDeprecated
process_vote_uncheckedDeprecated
“unchecked” functions used by tests and Tower
process_vote_unfilteredDeprecated
process_vote_with_accountDeprecated
update_commissionDeprecated
Update the vote account’s commission
update_validator_identityDeprecated
Update the node_pubkey, requires signature of the authorized voter
withdrawDeprecated
Withdraw funds from the vote account