pub struct VoteStateV3 {
pub node_pubkey: Address,
pub authorized_withdrawer: Address,
pub commission: u8,
pub votes: VecDeque<LandedVote>,
pub root_slot: Option<u64>,
pub authorized_voters: AuthorizedVoters,
pub prior_voters: CircBuf<(Address, u64, u64)>,
pub epoch_credits: Vec<(u64, u64, u64)>,
pub last_timestamp: BlockTimestamp,
}Fields
node_pubkey: Addressthe node that votes in this account
the signer for withdrawals
commission: u8percentage (0-100) that represents what part of a rewards payout should be given to this VoteAccount
votes: VecDeque<LandedVote>root_slot: Option<u64>the signer for vote transactions
prior_voters: CircBuf<(Address, u64, u64)>history of prior authorized voters and the epochs for which they were set, the bottom end of the range is inclusive, the top of the range is exclusive
epoch_credits: Vec<(u64, u64, u64)>history of how many credits earned by the end of each epoch each tuple is (Epoch, credits, prev_credits)
last_timestamp: BlockTimestampmost recent timestamp submitted with a vote
Implementations
Sourceimpl VoteStateV3
impl VoteStateV3
pub fn new(vote_init: &VoteInit, clock: &Clock) -> VoteStateV3
pub fn new_rand_for_tests(node_pubkey: Address, root_slot: u64) -> VoteStateV3
pub fn get_rent_exempt_reserve(rent: &Rent) -> u64
Use rent.minimum_balance(VoteStateV3::size_of()) directly
Sourcepub const fn size_of() -> usize
pub const fn size_of() -> usize
Upper limit on the size of the Vote State when votes.len() is MAX_LOCKOUT_HISTORY.
pub fn is_uninitialized(&self) -> bool
pub fn deserialize(input: &[u8]) -> Result<VoteStateV3, InstructionError>
Sourcepub fn deserialize_into(
input: &[u8],
vote_state: &mut VoteStateV3,
) -> Result<(), InstructionError>
pub fn deserialize_into( input: &[u8], vote_state: &mut VoteStateV3, ) -> Result<(), InstructionError>
Deserializes the input VoteStateVersions buffer directly into the provided VoteStateV3.
V0_23_5 is not supported. Supported versions: V1_14_11, V3.
On success, vote_state reflects the state of the input data. On failure, vote_state is
reset to VoteStateV3::default().
Sourcepub fn deserialize_into_uninit(
input: &[u8],
vote_state: &mut MaybeUninit<VoteStateV3>,
) -> Result<(), InstructionError>
pub fn deserialize_into_uninit( input: &[u8], vote_state: &mut MaybeUninit<VoteStateV3>, ) -> Result<(), InstructionError>
Deserializes the input VoteStateVersions buffer directly into the provided
MaybeUninit<VoteStateV3>.
V0_23_5 is not supported. Supported versions: V1_14_11, V3.
On success, vote_state is fully initialized and can be converted to
VoteStateV3 using
MaybeUninit::assume_init.
On failure, vote_state may still be uninitialized and must not be
converted to VoteStateV3.
pub fn serialize( versioned: &VoteStateVersions, output: &mut [u8], ) -> Result<(), InstructionError>
pub fn current_epoch(&self) -> u64
Sourcepub fn credits(&self) -> u64
pub fn credits(&self) -> u64
Number of “credits” owed to this account from the mining pool. Submit this VoteStateV3 to the Rewards program to trade credits for lamports.
pub fn is_correct_size_and_initialized(data: &[u8]) -> bool